# Change Log

Wichtige Änderungen am KMUHelper werden in dieser Datei dokumentiert.

## [1.1.3] - Future

### Added

### Changed

### Fixed

## [1.1.2] - 2020/11/03

### Added in 1.1.2

- Statistiken: Einschränkung der Ergebnisse mit Parametern
- E-Mail Log (Beta - `/admin/kmuhelper/email`)
- E-Mails online ansehen (Beta)

### Changed in 1.1.2

- Codestruktur nochmals angepasst
- Produkt-/ Kostenauswahl angepasst in Bestellung und Lieferung angepasst

### Fixed in 1.1.2

## [1.1.1] - 2020/10/10

### Added in 1.1.1

- E-Mail Vorlage
- Statistiken: Beste Produkte

### Changed in 1.1.1

- Codestruktur komplett überarbeitet
- Notiz aus Lieferungen entfernt -> Verlinkung mit Notiz möglich
- Einstellungen angepasst
  - Build Info wird später geladen (Ladezeit verkürzt)
  - Neue Typen: Wahrheitswert / E-Mail

### Fixed in 1.1.1

- Kleine Fehlerbehebungen

## [1.1] - 2020/10/09

### Added in 1.1

- KMUHelper Startseite `/kmuhelper`
- KMUHelper App V2
- Warnung bei geringem Lagerbestand
- Rabatte
- Build Info in den Einstellungen
- Dokumentation hinzugefügt
- Warnung bei ungültiger UID/IBAN eines Zahlungsempfängers
- Statistiken (Beta - `/kmuhelper/stats`)

### Changed in 1.1

- Kleine Designänderungen in der App V1
- `Start` im Admin-Bereich entfernt
- Diverse kleine Verbesserungen

### Fixed in 1.1

- Sprachdateien haben gefehlt
- Diverse kleine Fehler

## [1.0 and older]

Ältere Versionen sind nicht in diesem Changelog inbegriffen!
